@@ -89,7 +89,7 @@ def validate_settings(settings, settings_type, token_info=None, platform_name=No
     from stratus_api.integrations import get_integration_function, get_schema_values_recursive
 
     if 'rate' in settings.keys():
-        if not token_info or 'post:rate' not in token_info['scope']:
+        if token_info is not None and 'post:rate' not in token_info['scope']:
             raise ApiError('Only internal users can create destinations with a rate')
 
     template_mapping = dict(
