@@ -1,7 +1,7 @@
 from celery import shared_task
 
 
-@shared_task(bind=True, )
+@shared_task(bind=True, autoretry_for=(Exception,), retry_backoff=True, retry_jitter=True)
 def deliver_data_task(self, platform_name, bucket_name, file_pattern, segments, destination, file_headers, job_uuid,
                       id_types, operations,
                       **kwargs):
